summaryrefslogtreecommitdiffstats
path: root/kmobile/devices/skeleton/skeleton.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmobile/devices/skeleton/skeleton.h')
-rw-r--r--kmobile/devices/skeleton/skeleton.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmobile/devices/skeleton/skeleton.h b/kmobile/devices/skeleton/skeleton.h
index 6ae0287b..ab3ce770 100644
--- a/kmobile/devices/skeleton/skeleton.h
+++ b/kmobile/devices/skeleton/skeleton.h
@@ -42,14 +42,14 @@ public:
bool connectDevice(TQWidget *parent);
bool disconnectDevice(TQWidget *parent);
// returns true, if this tqdevice is read-only (default: false)
bool isReadOnly() const;
// you may provide your own icon() implementation to display
// an appropriate Pixmap (e.g. a Palm Pilot or a Zaurus image).
TQString iconFileName() const;
- TQString tqdeviceUniqueID();
+ TQString deviceUniqueID();
/*
* Addressbook / Phonebook support
@@ -42,14 +42,14 @@ public:
bool connectDevice(TQWidget *parent);
bool disconnectDevice(TQWidget *parent);
- // returns true, if this tqdevice is read-only (default: false)
+ // returns true, if this device is read-only (default: false)
bool isReadOnly() const;
// you may provide your own icon() implementation to display